==> igniteui-react-layouts-18.7.3.tgz: package/esm5/lib/igr-tool-action-checkbox-list.js <==
import { __extends } from "tslib";
import { IgrLayoutSelectedKeysCollection } from "./igr-layout-selected-keys-collection";
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionCheckboxList } from "./ToolActionCheckboxList";
import { LayoutSelectedKeysCollection as LayoutSelectedKeysCollection_internal } from "./LayoutSelectedKeysCollection";
import { LayoutPrimaryKeyValue } from "./LayoutPrimaryKeyValue";
import { SyncableObservableCollection$1 } from "igniteui-react-core";
var IgrToolActionCheckboxList = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrToolActionCheckboxList, _super);
    function IgrToolActionCheckboxList(props) {
        var _this = _super.call(this, props) || this;
        _this._selectedKeys = null;
        return _this;
    }
    IgrToolActionCheckboxList.prototype.createImplementation = function () {
        return new ToolActionCheckboxList();
    };
    Object.defineProperty(IgrToolActionCheckboxList.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckboxList.prototype, "dataSource", {
        /**
         * Gets or sets if the tool action is checked.
        */
        get: function () {
            return this.i.itemsSource;
        },
        set: function (v) {
            this.i.itemsSource = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckboxList.prototype, "selectedMemberPath", {
        /**
         * Gets or sets if the tool action is checked.
        */
        get: function () {
            return this.i.hr;
        },
        set: function (v) {
            this.i.hr = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckboxList.prototype, "dataMemberPath", {
        /**
         * Gets or sets if the tool action is checked.
        */
        get: function () {
            return this.i.hm;
        },
        set: function (v) {
            this.i.hm = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckboxList.prototype, "primaryKey", {
        /**
         * Gets or sets if the tool action is checked.
        */
        get: function () {
            return this.i.hb;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.hb = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckboxList.prototype, "selectedKeys", {
        /**
        
        */
        get: function () {
            if (this._selectedKeys === null) {
                var coll = new IgrLayoutSelectedKeysCollection();
                var innerColl = this.i.hc;
                if (!innerColl) {
                    innerColl = new LayoutSelectedKeysCollection_internal();
                }
                this._selectedKeys = coll._fromInner(innerColl);
                this.i.hc = innerColl;
            }
            return this._selectedKeys;
        },
        set: function (v) {
            if (this._selectedKeys !== null) {
                this._selectedKeys._setSyncTarget(null);
                this._selectedKeys = null;
            }
            var coll = new IgrLayoutSelectedKeysCollection();
            this._selectedKeys = coll._fromOuter(v);
            var syncColl = new SyncableObservableCollection$1(LayoutPrimaryKeyValue.$type);
            var innerColl = this.i.hc;
            if (!innerColl) {
                innerColl = new LayoutSelectedKeysCollection_internal();
            }
            syncColl._inner = innerColl;
            syncColl.clear();
            this._selectedKeys._setSyncTarget(syncColl);
            this.i.hc = innerColl;
        },
        enumerable: false,
        configurable: true
    });
    IgrToolActionCheckboxList.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.selectedKeys != null && this.selectedKeys.findByName && this.selectedKeys.findByName(name)) {
            return this.selectedKeys.findByName(name);
        }
        return null;
    };
    return IgrToolActionCheckboxList;
}(IgrToolAction));
export { IgrToolActionCheckboxList };

==> igniteui-react-layouts-18.7.5.tgz: package/esm5/lib/igr-tool-action-checkbox-list.js <==
import { __extends } from "tslib";
import { IgrLayoutSelectedKeysCollection } from "./igr-layout-selected-keys-collection";
import { ToolActionCheckboxListIndexType_$type } from "./ToolActionCheckboxListIndexType";
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionCheckboxList } from "./ToolActionCheckboxList";
import { ensureBool, ensureEnum } from "igniteui-react-core";
import { LayoutSelectedKeysCollection as LayoutSelectedKeysCollection_internal } from "./LayoutSelectedKeysCollection";
import { LayoutPrimaryKeyValue } from "./LayoutPrimaryKeyValue";
import { SyncableObservableCollection$1 } from "igniteui-react-core";
var IgrToolActionCheckboxList = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrToolActionCheckboxList, _super);
    function IgrToolActionCheckboxList(props) {
        var _this = _super.call(this, props) || this;
        _this._selectedKeys = null;
        return _this;
    }
    IgrToolActionCheckboxList.prototype.createImplementation = function () {
        return new ToolActionCheckboxList();
    };
    Object.defineProperty(IgrToolActionCheckboxList.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckboxList.prototype, "dataSource", {
        /**
         * Gets or sets if the tool action is checked.
        */
        get: function () {
            return this.i.itemsSource;
        },
        set: function (v) {
            this.i.itemsSource = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckboxList.prototype, "selectedMemberPath", {
        /**
         * Gets or sets if the tool action is checked.
        */
        get: function () {
            return this.i.ho;
        },
        set: function (v) {
            this.i.ho = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckboxList.prototype, "showSelectAll", {
        /**
         * Gets or sets if the select all row is shown.
        */
        get: function () {
            return this.i.hd;
        },
        set: function (v) {
            this.i.hd = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckboxList.prototype, "dataMemberPath", {
        /**
         * Gets or sets if the tool action is checked.
        */
        get: function () {
            return this.i.hi;
        },
        set: function (v) {
            this.i.hi = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckboxList.prototype, "primaryKey", {
        /**
         * Gets or sets if the tool action is checked.
        */
        get: function () {
            return this.i.g7;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.g7 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckboxList.prototype, "selectedKeys", {
        /**
        
        */
        get: function () {
            if (this._selectedKeys === null) {
                var coll = new IgrLayoutSelectedKeysCollection();
                var innerColl = this.i.g8;
                if (!innerColl) {
                    innerColl = new LayoutSelectedKeysCollection_internal();
                }
                this._selectedKeys = coll._fromInner(innerColl);
                this.i.g8 = innerColl;
            }
            return this._selectedKeys;
        },
        set: function (v) {
            if (this._selectedKeys !== null) {
                this._selectedKeys._setSyncTarget(null);
                this._selectedKeys = null;
            }
            var coll = new IgrLayoutSelectedKeysCollection();
            this._selectedKeys = coll._fromOuter(v);
            var syncColl = new SyncableObservableCollection$1(LayoutPrimaryKeyValue.$type);
            var innerColl = this.i.g8;
            if (!innerColl) {
                innerColl = new LayoutSelectedKeysCollection_internal();
            }
            syncColl._inner = innerColl;
            syncColl.clear();
            this._selectedKeys._setSyncTarget(syncColl);
            this.i.g8 = innerColl;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckboxList.prototype, "indexType", {
        /**
        
        */
        get: function () {
            return this.i.g9;
        },
        set: function (v) {
            this.i.g9 = ensureEnum(ToolActionCheckboxListIndexType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    IgrToolActionCheckboxList.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.selectedKeys != null && this.selectedKeys.findByName && this.selectedKeys.findByName(name)) {
            return this.selectedKeys.findByName(name);
        }
        return null;
    };
    return IgrToolActionCheckboxList;
}(IgrToolAction));
export { IgrToolActionCheckboxList };
